define(
//begin v1.x content
({
	"descTemplate": "${2} - ${3} av ${1} ${0}",
	"firstTip": "Första sidan",
	"lastTip": "Sista sidan",
	"nextTip": "Nästa sida",
	"prevTip": "Föregående sida",
	"itemTitle": "objekt",
	"singularItemTitle": "objekt",
	"pageStepLabelTemplate": "Sida ${0}",
	"pageSizeLabelTemplate": "${0} objekt per sida",
	"allItemsLabelTemplate": "Alla objekt",
	"gotoButtonTitle": "Gå till en viss sida",
	"dialogTitle": "Gå till sidan",
	"dialogIndication": "Ange sidnummer",
	"pageCountIndication": " (${0} sidor)",
	"dialogConfirm": "Gå",
	"dialogCancel": "Avbryt",
	"all": "alla"
})
//end v1.x content
);
